import os
# os.environ["DATA_URL"]          =  "https://localhost:1008"
# os.environ["QUERY_MANAGER"]     =  "http://localhost:1012"
# os.environ["INPUTSTREAM_URL"]   =  "https://localhost:1000"

from  acelerai_inputstream import InputstreamClient
import logging
import pandas as pd

logging.basicConfig(level=logging.INFO, format='%(asctime)s - %(levelname)s - %(name)s - %(message)s')

#Para desactivar los logs de la librería
logging.getLogger('InputstreamClient').disabled = False

#pat_danilo='324738f335354e9d80394c31ce1d644c'
client = InputstreamClient(token='084a45f10e3b4952a4f3a7df04f546e5') 

input_cycle=client.find(ikey='74c337b0e99a45ac8a9c', query= {}, cache=False)
df=pd.DataFrame(input_cycle)
#print(len(df))


import json
import os
from acelerai_inputstream.inputstream import INSERTION_MODE, Inputstream
from acelerai_inputstream.inputstream_client import InputstreamClient

__results_path = os.environ.get("A2G_RESULT_PATH","a2g_results")
__payload_path = os.environ.get("A2G_PAYLOAD_PATH", "payload.json")

__mode = os.environ.get("EXEC_LOCATION", "LOCAL")

def save_result(key:str, value, path = None):
    """
    Save the result in the file
    :param key: The key to be used to save the result
    :param value: The value to be saved
    :param path: The path to save the result, if None, the default path is used
    """
    result_path = __results_path
    if path is not None and __mode == "LOCAL":
        result_path = path

    if __mode == "LOCAL":
        if not os.path.exists(result_path): os.makedirs(result_path)

    open(f"{result_path}/{key}", 'w+').write(json.dumps(value))

def get_payload(path = None) -> dict | None:
    """
    Get the payload from the file, if the file does not exist, return None
    :param path: The path to the payload file, if None, the default path is used
    """
    payload_path = __payload_path
    if path is not None and __mode == "LOCAL":
        payload_path = path

    if not os.path.exists(payload_path): return None
    return json.loads(open(payload_path).read())





import setuptools


setuptools.setup(
    name = "acelerai",
    version = "0.0.5",
    author = "DaniloAraneda",
    author_email = "danilo@alert2gain.com",
    description = "short package description",
    classifiers = [
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    package_dir = {"": "src"},
    packages = setuptools.find_packages(where="src"),
    include_dirs=[],
    python_requires = ">=3.10.7",
    install_requires = [
        "anyio==4.8.0",
        "certifi>=2024.7.4",
        "charset-normalizer>=3.3.2",
        "exceptiongroup>=1.2.2",
        "fastjsonschema==2.21.1",
        "h11>=0.14.0",
        "h2==4.1.0",
        "hpack==4.0.0",
        "httpcore==1.0.7",
        "httpx==0.28.1",
        "hyperframe==6.0.1",
        "idna>=3.7",
        "msgpack==1.1.0",
        "python-dateutil>=2.9.0.post0",
        "requests>=2.32.3",
        "six>=1.16.0",
        "sniffio==1.3.1",
        "typing_extensions>=4.12.2",
        "urllib3>=2.2.2"
   ]
)